Index: trunk/src/org/openstreetmap/josm/tools/BugReportExceptionHandler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/BugReportExceptionHandler.java	(revision 7406)
+++ trunk/src/org/openstreetmap/josm/tools/BugReportExceptionHandler.java	(revision 7407)
@@ -106,4 +106,5 @@
                         }
                         ed.setContent(pnl);
+                        ed.setFocusOnDefaultButton(true);
                         ed.showDialog();
                         if (cbSuppress != null && cbSuppress.isSelected()) {

Index: trunk/src/org/openstreetmap/josm/gui/ExtendedDialog.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/ExtendedDialog.java	(revision 7406)
+++ trunk/src/org/openstreetmap/josm/gui/ExtendedDialog.java	(revision 7407)
@@ -88,4 +88,5 @@
     private Icon icon;
     private boolean modal;
+    private boolean focusOnDefaultButton = false;
 
     /** true, if the dialog should include a help button */
@@ -278,5 +279,8 @@
             getRootPane().setDefaultButton(defaultButton);
         }
-        fixFocus();
+        // Don't focus the "do not show this again" check box, but the default button.
+        if (toggleable || focusOnDefaultButton) {
+            requestFocusToDefaultButton();
+        }
         setVisible(true);
         toggleSaveState();
@@ -558,7 +562,13 @@
 
     /**
-     * Always makes sure the default button has initial focus.
-     */
-    protected void fixFocus() {
+     * Makes default button request initial focus or not.
+     * @param focus {@code true} to make default button request initial focus
+     * @since 7407
+     */
+    public void setFocusOnDefaultButton(boolean focus) {
+        focusOnDefaultButton = focus;
+    }
+
+    private void requestFocusToDefaultButton() {
         if (defaultButton != null) {
             GuiHelper.runInEDT(new Runnable() {